Config

Struct Config 

pub struct Config { /* private fields */ }
Implements a client for the Infrastructure Manager API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = Config::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_deployments()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Infrastructure Manager is a managed service that automates the deployment and management of Google Cloud infrastructure resources.

Configuration

To configure Config use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://config.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

Config holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap Config in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl Config

pub fn builder() -> ClientBuilder

Returns a builder for Config.

let client = Config::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: Config + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn list_deployments(&self) -> ListDeployments

Lists Deployments in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let mut list = client.list_deployments()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_deployment(&self) -> GetDeployment

Gets details about a Deployment.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.get_deployment()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_deployment(&self) -> CreateDeployment

Creates a Deployment.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_config_v1::model::Deployment;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let response = client.create_deployment()
        .set_parent(parent)
        .set_deployment_id("deployment_id_value")
        .set_deployment(
            Deployment::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_deployment(&self) -> UpdateDeployment

Updates a Deployment.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_config_v1::model::Deployment;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.update_deployment()
        .set_deployment(
            Deployment::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_deployment(&self) -> DeleteDeployment

Deletes a Deployment.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.delete_deployment()
        .set_name(name)
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_revisions(&self) -> ListRevisions

Lists Revisions of a deployment.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let mut list = client.list_revisions()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_revision(&self) -> GetRevision

Gets details about a Revision.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.get_revision()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_resource(&self) -> GetResource

Gets details about a Resource deployed by Infra Manager.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.get_resource()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_resources(&self) -> ListResources

Lists Resources in a given revision.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let mut list = client.list_resources()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn export_deployment_statefile(&self) -> ExportDeploymentStatefile

Exports Terraform state file from a given deployment.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.export_deployment_statefile()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn export_revision_statefile(&self) -> ExportRevisionStatefile

Exports Terraform state file from a given revision.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.export_revision_statefile()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn import_statefile(&self) -> ImportStatefile

Imports Terraform state file in a given deployment. The state file does not take effect until the Deployment has been unlocked.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.import_statefile()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_statefile(&self) -> DeleteStatefile

Deletes Terraform state file in a given deployment.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    client.delete_statefile()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn lock_deployment(&self) -> LockDeployment

Locks a deployment.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.lock_deployment()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn unlock_deployment(&self) -> UnlockDeployment

Unlocks a locked deployment.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.unlock_deployment()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn export_lock_info(&self) -> ExportLockInfo

Exports the lock info on a locked deployment.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.export_lock_info()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_preview(&self) -> CreatePreview

Creates a Preview.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_config_v1::model::Preview;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let response = client.create_preview()
        .set_parent(parent)
        .set_preview_id("preview_id_value")
        .set_preview(
            Preview::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_preview(&self) -> GetPreview

Gets details about a Preview.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.get_preview()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_previews(&self) -> ListPreviews

Lists Previews in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let mut list = client.list_previews()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn delete_preview(&self) -> DeletePreview

Deletes a Preview.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.delete_preview()
        .set_name(name)
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn export_preview_result(&self) -> ExportPreviewResult

Export Preview results.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.export_preview_result()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_terraform_versions(&self) -> ListTerraformVersions

Lists TerraformVersions in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let mut list = client.list_terraform_versions()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_terraform_version(&self) -> GetTerraformVersion

Gets details about a TerraformVersion.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.get_terraform_version()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_resource_changes(&self) -> ListResourceChanges

Lists ResourceChanges for a given preview.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let mut list = client.list_resource_changes()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_resource_change(&self) -> GetResourceChange

Get a ResourceChange for a given preview.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.get_resource_change()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_resource_drifts(&self) -> ListResourceDrifts

List ResourceDrifts for a given preview.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let mut list = client.list_resource_drifts()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_resource_drift(&self) -> GetResourceDrift

Get a ResourceDrift for a given preview.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.get_resource_drift()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_auto_migration_config(&self) -> GetAutoMigrationConfig

Get the AutoMigrationConfig for a given project and location.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.get_auto_migration_config()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_auto_migration_config(&self) -> UpdateAutoMigrationConfig

Updates the AutoMigrationConfig for a given project and location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_config_v1::model::AutoMigrationConfig;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.update_auto_migration_config()
        .set_auto_migration_config(
            AutoMigrationConfig::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_deployment_group(&self) -> GetDeploymentGroup

Get a DeploymentGroup for a given project and location.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.get_deployment_group()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_deployment_group(&self) -> CreateDeploymentGroup

Creates a DeploymentGroup The newly created DeploymentGroup will be in the CREATING state and can be retrieved via Get and List calls.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_config_v1::model::DeploymentGroup;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let response = client.create_deployment_group()
        .set_parent(parent)
        .set_deployment_group(
            DeploymentGroup::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_deployment_group(&self) -> UpdateDeploymentGroup

Updates a DeploymentGroup

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_config_v1::model::DeploymentGroup;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.update_deployment_group()
        .set_deployment_group(
            DeploymentGroup::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_deployment_group(&self) -> DeleteDeploymentGroup

Deletes a DeploymentGroup

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.delete_deployment_group()
        .set_name(name)
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_deployment_groups(&self) -> ListDeploymentGroups

List DeploymentGroups for a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let mut list = client.list_deployment_groups()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn provision_deployment_group(&self) -> ProvisionDeploymentGroup

Provisions a deployment group.

NOTE: As a first step of this operation, Infra Manager will automatically delete any Deployments that were part of the last successful DeploymentGroupRevision but are no longer included in the current DeploymentGroup definition (e.g., following an UpdateDeploymentGroup call), along with their actuated resources.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.provision_deployment_group()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn deprovision_deployment_group(&self) -> DeprovisionDeploymentGroup

Deprovisions a deployment group.

NOTE: As a first step of this operation, Infra Manager will automatically delete any Deployments that were part of the last successful DeploymentGroupRevision but are no longer included in the current DeploymentGroup definition (e.g., following an UpdateDeploymentGroup call), along with their actuated resources.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.deprovision_deployment_group()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_deployment_group_revision(&self) -> GetDeploymentGroupRevision

Gets details about a DeploymentGroupRevision.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, name: &str
) -> Result<()> {
    let response = client.get_deployment_group_revision()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_deployment_group_revisions(&self) -> ListDeploymentGroupRevisions

Lists DeploymentGroupRevisions in a given DeploymentGroup.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config, parent: &str
) -> Result<()> {
    let mut list = client.list_deployment_group_revisions()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:

  • Global locations: If name is empty, the method lists the public locations available to all projects. * Project-specific locations: If name follows the format projects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.

For gRPC and client library implementations, the resource name is passed as the name field. For direct service calls, the resource name is incorporated into the request path based on the specific service implementation and version.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_config_v1::Result;
async fn sample(
   client: &Config
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}