#[non_exhaustive]pub enum DeploymentReferencePolicy {
Unspecified,
FailIfAnyReferencesExist,
FailIfMetadataReferencesExist,
IgnoreDeploymentReferences,
UnknownValue(UnknownValue),
}Expand description
Policy on how to handle referenced deployments when deleting the DeploymentGroup.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default behavior. If unspecified, the system will act as if
FAIL_IF_ANY_REFERENCES_EXIST is specified.
FailIfAnyReferencesExist
Fail the deletion if any deployments currently referenced in the
deployment_units of the DeploymentGroup or in the latest revision
are not deleted.
FailIfMetadataReferencesExist
Fail the deletion only if any deployments currently referenced in the
deployment_units of the DeploymentGroup are not deleted.
The deletion will proceed even if the deployments in the latest revision
of the DeploymentGroup are not deleted.
IgnoreDeploymentReferences
Ignore any deployments currently referenced in the
deployment_units of the DeploymentGroup or in the latest revision.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DeploymentReferencePolicy::value or DeploymentReferencePolicy::name.
Implementations