#[non_exhaustive]pub enum LockState {
Unspecified,
Locked,
Unlocked,
Locking,
Unlocking,
LockFailed,
UnlockFailed,
UnknownValue(UnknownValue),
}Expand description
Possible lock states of a deployment.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
The default value. This value is used if the lock state is omitted.
Locked
The deployment is locked.
Unlocked
The deployment is unlocked.
Locking
The deployment is being locked.
Unlocking
The deployment is being unlocked.
LockFailed
The deployment has failed to lock.
UnlockFailed
The deployment has failed to unlock.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LockState::value or LockState::name.
Implementations