#[non_exhaustive]pub enum ProvisioningState {
Unspecified,
Provisioning,
Provisioned,
FailedToProvision,
Deprovisioning,
Deprovisioned,
FailedToDeprovision,
UnknownValue(UnknownValue),
}Expand description
Possible provisioning states of a deployment group.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified provisioning state.
Provisioning
The deployment group is being provisioned.
Provisioned
The deployment group is provisioned.
FailedToProvision
The deployment group failed to be provisioned.
Deprovisioning
The deployment group is being deprovisioned.
Deprovisioned
The deployment group is deprovisioned.
FailedToDeprovision
The deployment group failed to be deprovisioned.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ProvisioningState::value or ProvisioningState::name.
Implementations