#[non_exhaustive]pub enum DeploymentStep {
Show 14 variants
Unspecified,
PreparingStorageBucket,
DownloadingBlueprint,
RunningTfInit,
RunningTfPlan,
RunningTfApply,
RunningTfDestroy,
RunningTfValidate,
UnlockingDeployment,
Succeeded,
Failed,
ValidatingRepository,
RunningQuotaValidation,
UnknownValue(UnknownValue),
}Expand description
The possible steps a deployment may be running.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified deployment step
PreparingStorageBucket
Infra Manager is creating a Google Cloud Storage bucket to store artifacts and metadata about the deployment and revision
DownloadingBlueprint
Downloading the blueprint onto the Google Cloud Storage bucket
RunningTfInit
Initializing Terraform using terraform init
RunningTfPlan
Running terraform plan
RunningTfApply
Actuating resources using Terraform using terraform apply
RunningTfDestroy
Destroying resources using Terraform using terraform destroy
RunningTfValidate
Validating the uploaded TF state file when unlocking a deployment
UnlockingDeployment
Unlocking a deployment
Succeeded
Operation was successful
Failed
Operation failed
ValidatingRepository
Validating the provided repository.
RunningQuotaValidation
Running quota validation
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DeploymentStep::value or DeploymentStep::name.
Implementations