#[non_exhaustive]pub enum Intent {
Unspecified,
CreateDeployment,
UpdateDeployment,
DeleteDeployment,
RecreateDeployment,
CleanUp,
Unchanged,
UnknownValue(UnknownValue),
}Expand description
The possible intents of a deployment unit.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified intent.
CreateDeployment
Create deployment in the unit from the deployment spec.
UpdateDeployment
Update deployment in the unit.
DeleteDeployment
Delete deployment in the unit.
RecreateDeployment
Recreate deployment in the unit.
CleanUp
Delete deployment in latest successful revision while no longer referenced in any deployment unit in the current deployment group.
Unchanged
Expected to be unchanged.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Intent::value or Intent::name.
Implementations