#[non_exhaustive]pub enum State {
Unspecified,
Queued,
ApplyingDeployment,
Succeeded,
Failed,
Aborted,
Skipped,
DeletingDeployment,
PreviewingDeployment,
UnknownValue(UnknownValue),
}Expand description
The possible steps a deployment unit provisioning may be running.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default value. This value is unused.
Queued
The deployment unit is queued for deployment creation or update.
ApplyingDeployment
The underlying deployment of the unit is being created or updated.
Succeeded
The underlying deployment operation of the unit has succeeded.
Failed
The underlying deployment operation of the unit has failed.
Aborted
The deployment unit was aborted, likely due to failures in other dependent deployment units.
Skipped
The deployment unit was skipped because there were no changes to apply.
DeletingDeployment
The deployment is being deleted.
PreviewingDeployment
The deployment is being previewed.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations