#[non_exhaustive]pub enum PreviewMode {
Unspecified,
Default,
Delete,
UnknownValue(UnknownValue),
}Expand description
Preview mode provides options for customizing preview operations.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified policy, default mode will be used.
Default
DEFAULT mode generates an execution plan for reconciling current resource state into expected resource state.
Delete
DELETE mode generates as execution plan for destroying current resources.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using PreviewMode::value or PreviewMode::name.
Implementations