#[non_exhaustive]pub enum PreviewStep {
Unspecified,
PreparingStorageBucket,
DownloadingBlueprint,
RunningTfInit,
RunningTfPlan,
FetchingDeployment,
LockingDeployment,
UnlockingDeployment,
Succeeded,
Failed,
ValidatingRepository,
UnknownValue(UnknownValue),
}Expand description
The possible steps a preview may be running.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified preview step.
PreparingStorageBucket
Infra Manager is creating a Google Cloud Storage bucket to store artifacts and metadata about the preview.
DownloadingBlueprint
Downloading the blueprint onto the Google Cloud Storage bucket.
RunningTfInit
Initializing Terraform using terraform init.
RunningTfPlan
Running terraform plan.
FetchingDeployment
Fetching a deployment.
LockingDeployment
Locking a deployment.
UnlockingDeployment
Unlocking a deployment.
Succeeded
Operation was successful.
Failed
Operation failed.
ValidatingRepository
Validating the provided repository.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using PreviewStep::value or PreviewStep::name.
Implementations