#[non_exhaustive]pub enum ErrorCode {
Unspecified,
CloudBuildPermissionDenied,
ApplyBuildApiFailed,
ApplyBuildRunFailed,
QuotaValidationFailed,
ExternalValueSourceImportFailed,
UnknownValue(UnknownValue),
}Expand description
Possible errors if Revision could not be created or updated successfully.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
No error code was specified.
CloudBuildPermissionDenied
Cloud Build failed due to a permission issue.
ApplyBuildApiFailed
Cloud Build job associated with creating or updating a deployment could not be started.
ApplyBuildRunFailed
Cloud Build job associated with creating or updating a deployment was started but failed.
QuotaValidationFailed
quota validation failed for one or more resources in terraform configuration files.
ExternalValueSourceImportFailed
Failed to import values from an external source.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ErrorCode::value or ErrorCode::name.
Implementations