#[non_exhaustive]pub struct CreateDeploymentRequest {
pub parent: String,
pub deployment_id: String,
pub deployment: Option<Deployment>,
pub request_id: String,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent in whose context the Deployment is created. The parent value is in the format: ‘projects/{project_id}/locations/{location}’.
deployment_id: StringRequired. The Deployment ID.
deployment: Option<Deployment>Required. Deployment resource to be created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateDeploymentRequest
impl CreateDeploymentRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_deployment_id<T: Into<String>>(self, v: T) -> Self
pub fn set_deployment_id<T: Into<String>>(self, v: T) -> Self
Sets the value of deployment_id.
Example
let x = CreateDeploymentRequest::new().set_deployment_id("example");Sourcepub fn set_deployment<T>(self, v: T) -> Selfwhere
T: Into<Deployment>,
pub fn set_deployment<T>(self, v: T) -> Selfwhere
T: Into<Deployment>,
Sets the value of deployment.
Example
use google_cloud_config_v1::model::Deployment;
let x = CreateDeploymentRequest::new().set_deployment(Deployment::default()/* use setters */);Sourcepub fn set_or_clear_deployment<T>(self, v: Option<T>) -> Selfwhere
T: Into<Deployment>,
pub fn set_or_clear_deployment<T>(self, v: Option<T>) -> Selfwhere
T: Into<Deployment>,
Sets or clears the value of deployment.
Example
use google_cloud_config_v1::model::Deployment;
let x = CreateDeploymentRequest::new().set_or_clear_deployment(Some(Deployment::default()/* use setters */));
let x = CreateDeploymentRequest::new().set_or_clear_deployment(None::<Deployment>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateDeploymentRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateDeploymentRequest
impl Clone for CreateDeploymentRequest
Sourcefn clone(&self) -> CreateDeploymentRequest
fn clone(&self) -> CreateDeploymentRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateDeploymentRequest
impl Debug for CreateDeploymentRequest
Sourceimpl Default for CreateDeploymentRequest
impl Default for CreateDeploymentRequest
Sourcefn default() -> CreateDeploymentRequest
fn default() -> CreateDeploymentRequest
Sourceimpl Message for CreateDeploymentRequest
impl Message for CreateDeploymentRequest
Sourceimpl PartialEq for CreateDeploymentRequest
impl PartialEq for CreateDeploymentRequest
impl StructuralPartialEq for CreateDeploymentRequest