#[non_exhaustive]pub struct CreatePreviewRequest {
pub parent: String,
pub preview_id: String,
pub preview: Option<Preview>,
pub request_id: String,
/* private fields */
}Expand description
A request to create a preview.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent in whose context the Preview is created. The parent value is in the format: ‘projects/{project_id}/locations/{location}’.
preview_id: StringOptional. The preview ID.
preview: Option<Preview>Required. Preview resource to be created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreatePreviewRequest
impl CreatePreviewRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_preview_id<T: Into<String>>(self, v: T) -> Self
pub fn set_preview_id<T: Into<String>>(self, v: T) -> Self
Sets the value of preview_id.
Example
let x = CreatePreviewRequest::new().set_preview_id("example");Sourcepub fn set_preview<T>(self, v: T) -> Self
pub fn set_preview<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_preview<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_preview<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreatePreviewRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreatePreviewRequest
impl Clone for CreatePreviewRequest
Sourcefn clone(&self) -> CreatePreviewRequest
fn clone(&self) -> CreatePreviewRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreatePreviewRequest
impl Debug for CreatePreviewRequest
Sourceimpl Default for CreatePreviewRequest
impl Default for CreatePreviewRequest
Sourcefn default() -> CreatePreviewRequest
fn default() -> CreatePreviewRequest
Sourceimpl Message for CreatePreviewRequest
impl Message for CreatePreviewRequest
Sourceimpl PartialEq for CreatePreviewRequest
impl PartialEq for CreatePreviewRequest
impl StructuralPartialEq for CreatePreviewRequest