#[non_exhaustive]pub struct DeleteDeploymentGroupRequest {
pub name: String,
pub request_id: String,
pub force: bool,
pub deployment_reference_policy: DeploymentReferencePolicy,
/* private fields */
}Expand description
Request message for Delete DeploymentGroup
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of DeploymentGroup in the format projects/{project_id}/locations/{location_id}/deploymentGroups/{deploymentGroup}
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
force: boolOptional. If set to true, any revisions for this deployment group will also be deleted. (Otherwise, the request will only work if the deployment group has no revisions.)
deployment_reference_policy: DeploymentReferencePolicyOptional. Policy on how to handle referenced deployments when deleting the
DeploymentGroup.
If unspecified, the default behavior is to fail the deletion if any
deployments currently referenced in the deployment_units of the
DeploymentGroup or in the latest revision are not deleted.
Implementations
Sourceimpl DeleteDeploymentGroupRequest
impl DeleteDeploymentGroupRequest
pub fn new() -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = DeleteDeploymentGroupRequest::new().set_request_id("example");Sourcepub fn set_deployment_reference_policy<T: Into<DeploymentReferencePolicy>>(
self,
v: T,
) -> Self
pub fn set_deployment_reference_policy<T: Into<DeploymentReferencePolicy>>( self, v: T, ) -> Self
Sets the value of deployment_reference_policy.
Example
use google_cloud_config_v1::model::delete_deployment_group_request::DeploymentReferencePolicy;
let x0 = DeleteDeploymentGroupRequest::new().set_deployment_reference_policy(DeploymentReferencePolicy::FailIfAnyReferencesExist);
let x1 = DeleteDeploymentGroupRequest::new().set_deployment_reference_policy(DeploymentReferencePolicy::FailIfMetadataReferencesExist);
let x2 = DeleteDeploymentGroupRequest::new().set_deployment_reference_policy(DeploymentReferencePolicy::IgnoreDeploymentReferences);Trait Implementations
Sourceimpl Clone for DeleteDeploymentGroupRequest
impl Clone for DeleteDeploymentGroupRequest
Sourcefn clone(&self) -> DeleteDeploymentGroupRequest
fn clone(&self) -> DeleteDeploymentGroupRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DeleteDeploymentGroupRequest
impl Debug for DeleteDeploymentGroupRequest
Sourceimpl Default for DeleteDeploymentGroupRequest
impl Default for DeleteDeploymentGroupRequest
Sourcefn default() -> DeleteDeploymentGroupRequest
fn default() -> DeleteDeploymentGroupRequest
Sourceimpl PartialEq for DeleteDeploymentGroupRequest
impl PartialEq for DeleteDeploymentGroupRequest
Sourcefn eq(&self, other: &DeleteDeploymentGroupRequest) -> bool
fn eq(&self, other: &DeleteDeploymentGroupRequest) -> bool
self and other values to be equal, and is used by ==.