#[non_exhaustive]pub struct DeleteDeploymentRequest {
pub name: String,
pub request_id: String,
pub force: bool,
pub delete_policy: DeletePolicy,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the Deployment in the format: ‘projects/{project_id}/locations/{location}/deployments/{deployment}’.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
force: boolOptional. If set to true, any revisions for this deployment will also be deleted. (Otherwise, the request will only work if the deployment has no revisions.)
delete_policy: DeletePolicyOptional. Policy on how resources actuated by the deployment should be deleted. If unspecified, the default behavior is to delete the underlying resources.
Implementations
Sourceimpl DeleteDeploymentRequest
impl DeleteDeploymentRequest
pub fn new() -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = DeleteDeploymentRequest::new().set_request_id("example");Sourcepub fn set_delete_policy<T: Into<DeletePolicy>>(self, v: T) -> Self
pub fn set_delete_policy<T: Into<DeletePolicy>>(self, v: T) -> Self
Sets the value of delete_policy.
Example
use google_cloud_config_v1::model::delete_deployment_request::DeletePolicy;
let x0 = DeleteDeploymentRequest::new().set_delete_policy(DeletePolicy::Delete);
let x1 = DeleteDeploymentRequest::new().set_delete_policy(DeletePolicy::Abandon);Trait Implementations
Sourceimpl Clone for DeleteDeploymentRequest
impl Clone for DeleteDeploymentRequest
Sourcefn clone(&self) -> DeleteDeploymentRequest
fn clone(&self) -> DeleteDeploymentRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more