#[non_exhaustive]pub struct DeleteStatefileRequest {
pub name: String,
pub lock_id: i64,
/* private fields */
}Expand description
A request to delete a state file passed to a ‘DeleteStatefile’ call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the deployment in the format: ‘projects/{project_id}/locations/{location}/deployments/{deployment}’.
lock_id: i64Required. Lock ID of the lock file to verify that the user who is deleting the state file previously locked the Deployment.
Implementations