#[non_exhaustive]pub struct DeploymentGroup {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub annotations: HashMap<String, String>,
pub state: State,
pub state_description: String,
pub deployment_units: Vec<DeploymentUnit>,
pub provisioning_state: ProvisioningState,
pub provisioning_state_description: String,
pub provisioning_error: Option<Status>,
/* private fields */
}Expand description
A DeploymentGroup is a collection of DeploymentUnits that in a DAG-like structure.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of the deployment group. Format: ‘projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}’.
create_time: Option<Timestamp>Output only. Time when the deployment group was created.
update_time: Option<Timestamp>Output only. Time when the deployment group was last updated.
labels: HashMap<String, String>Optional. User-defined metadata for the deployment group.
annotations: HashMap<String, String>Optional. Arbitrary key-value metadata storage e.g. to help client tools identify deployment group during automation. See https://google.aip.dev/148#annotations for details on format and size limitations.
state: StateOutput only. Current state of the deployment group.
state_description: StringOutput only. Additional information regarding the current state.
deployment_units: Vec<DeploymentUnit>The deployment units of the deployment group in a DAG like structure. When a deployment group is being provisioned, the deployment units are deployed in a DAG order. The provided units must be in a DAG order, otherwise an error will be returned.
provisioning_state: ProvisioningStateOutput only. The provisioning state of the deployment group.
provisioning_state_description: StringOutput only. Additional information regarding the current provisioning state.
provisioning_error: Option<Status>Output only. The error status of the deployment group provisioning or deprovisioning.
Implementations
Sourceimpl DeploymentGroup
impl DeploymentGroup
pub fn new() -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DeploymentGroup::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DeploymentGroup::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DeploymentGroup::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = DeploymentGroup::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = DeploymentGroup::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DeploymentGroup::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = DeploymentGroup::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_state_description<T: Into<String>>(self, v: T) -> Self
pub fn set_state_description<T: Into<String>>(self, v: T) -> Self
Sets the value of state_description.
Example
let x = DeploymentGroup::new().set_state_description("example");Sourcepub fn set_deployment_units<T, V>(self, v: T) -> Self
pub fn set_deployment_units<T, V>(self, v: T) -> Self
Sets the value of deployment_units.
Example
use google_cloud_config_v1::model::DeploymentUnit;
let x = DeploymentGroup::new()
.set_deployment_units([
DeploymentUnit::default()/* use setters */,
DeploymentUnit::default()/* use (different) setters */,
]);Sourcepub fn set_provisioning_state<T: Into<ProvisioningState>>(self, v: T) -> Self
pub fn set_provisioning_state<T: Into<ProvisioningState>>(self, v: T) -> Self
Sets the value of provisioning_state.
Example
use google_cloud_config_v1::model::deployment_group::ProvisioningState;
let x0 = DeploymentGroup::new().set_provisioning_state(ProvisioningState::Provisioning);
let x1 = DeploymentGroup::new().set_provisioning_state(ProvisioningState::Provisioned);
let x2 = DeploymentGroup::new().set_provisioning_state(ProvisioningState::FailedToProvision);Sourcepub fn set_provisioning_state_description<T: Into<String>>(self, v: T) -> Self
pub fn set_provisioning_state_description<T: Into<String>>(self, v: T) -> Self
Sets the value of provisioning_state_description.
Example
let x = DeploymentGroup::new().set_provisioning_state_description("example");Sourcepub fn set_provisioning_error<T>(self, v: T) -> Self
pub fn set_provisioning_error<T>(self, v: T) -> Self
Sets the value of provisioning_error.
Example
use google_cloud_rpc::model::Status;
let x = DeploymentGroup::new().set_provisioning_error(Status::default()/* use setters */);Sourcepub fn set_or_clear_provisioning_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_provisioning_error<T>(self, v: Option<T>) -> Self
Sets or clears the value of provisioning_error.
Example
use google_cloud_rpc::model::Status;
let x = DeploymentGroup::new().set_or_clear_provisioning_error(Some(Status::default()/* use setters */));
let x = DeploymentGroup::new().set_or_clear_provisioning_error(None::<Status>);Trait Implementations
Sourceimpl Clone for DeploymentGroup
impl Clone for DeploymentGroup
Sourcefn clone(&self) -> DeploymentGroup
fn clone(&self) -> DeploymentGroup
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more