#[non_exhaustive]pub struct DeploymentGroupRevision {
pub name: String,
pub snapshot: Option<DeploymentGroup>,
pub create_time: Option<Timestamp>,
pub alternative_ids: Vec<String>,
/* private fields */
}Expand description
A DeploymentGroupRevision represents a snapshot of a DeploymentGroup at a given point in time, created when a DeploymentGroup is provisioned or deprovisioned.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of the deployment group revision. Format: ‘projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}/revisions/{revision}’.
snapshot: Option<DeploymentGroup>Output only. The snapshot of the deployment group at this revision.
create_time: Option<Timestamp>Output only. Time when the deployment group revision was created.
alternative_ids: Vec<String>Output only. The alternative IDs of the deployment group revision.
Implementations
Sourceimpl DeploymentGroupRevision
impl DeploymentGroupRevision
pub fn new() -> Self
Sourcepub fn set_snapshot<T>(self, v: T) -> Selfwhere
T: Into<DeploymentGroup>,
pub fn set_snapshot<T>(self, v: T) -> Selfwhere
T: Into<DeploymentGroup>,
Sourcepub fn set_or_clear_snapshot<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeploymentGroup>,
pub fn set_or_clear_snapshot<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeploymentGroup>,
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = DeploymentGroupRevision::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = DeploymentGroupRevision::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DeploymentGroupRevision::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_alternative_ids<T, V>(self, v: T) -> Self
pub fn set_alternative_ids<T, V>(self, v: T) -> Self
Sets the value of alternative_ids.
Example
ⓘ
let x = DeploymentGroupRevision::new().set_alternative_ids(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for DeploymentGroupRevision
impl Clone for DeploymentGroupRevision
Sourcefn clone(&self) -> DeploymentGroupRevision
fn clone(&self) -> DeploymentGroupRevision
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeploymentGroupRevision
impl Debug for DeploymentGroupRevision
Sourceimpl Default for DeploymentGroupRevision
impl Default for DeploymentGroupRevision
Sourcefn default() -> DeploymentGroupRevision
fn default() -> DeploymentGroupRevision
Returns the “default value” for a type. Read more
Sourceimpl Message for DeploymentGroupRevision
impl Message for DeploymentGroupRevision
Sourceimpl PartialEq for DeploymentGroupRevision
impl PartialEq for DeploymentGroupRevision
impl StructuralPartialEq for DeploymentGroupRevision