#[non_exhaustive]pub struct DeploymentSource {
pub deployment: String,
pub output_name: String,
/* private fields */
}Expand description
Configuration for a value sourced from a Deployment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.deployment: StringRequired. The resource name of the source Deployment to import the output from. Format: projects/{project}/locations/{location}/deployments/{deployment} The source deployment must be in the same project and location.
output_name: StringRequired. The name of the output variable in the source deployment’s latest successfully applied revision.
Implementations
Sourceimpl DeploymentSource
impl DeploymentSource
pub fn new() -> Self
Sourcepub fn set_deployment<T: Into<String>>(self, v: T) -> Self
pub fn set_deployment<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_output_name<T: Into<String>>(self, v: T) -> Self
pub fn set_output_name<T: Into<String>>(self, v: T) -> Self
Sets the value of output_name.
Example
ⓘ
let x = DeploymentSource::new().set_output_name("example");Trait Implementations
Sourceimpl Clone for DeploymentSource
impl Clone for DeploymentSource
Sourcefn clone(&self) -> DeploymentSource
fn clone(&self) -> DeploymentSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeploymentSource
impl Debug for DeploymentSource
Sourceimpl Default for DeploymentSource
impl Default for DeploymentSource
Sourcefn default() -> DeploymentSource
fn default() -> DeploymentSource
Returns the “default value” for a type. Read more
Sourceimpl Message for DeploymentSource
impl Message for DeploymentSource
Sourceimpl PartialEq for DeploymentSource
impl PartialEq for DeploymentSource
impl StructuralPartialEq for DeploymentSource