DeprovisionDeploymentGroupRequest

Struct DeprovisionDeploymentGroupRequest 

#[non_exhaustive]
pub struct DeprovisionDeploymentGroupRequest { pub name: String, pub force: bool, pub delete_policy: DeletePolicy, /* private fields */ }
The request message for the DeprovisionDeploymentGroup method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The name of the deployment group to deprovision. Format: ‘projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}’.

force: bool

Optional. If set to true, this option is propagated to the deletion of each deployment in the group. This corresponds to the ‘force’ field in DeleteDeploymentRequest.

delete_policy: DeletePolicy

Optional. Policy on how resources within each deployment should be handled during deletion. This policy is applied globally to the deletion of all deployments in this group. This corresponds to the ‘delete_policy’ field in DeleteDeploymentRequest.

Implementations

Source

impl DeprovisionDeploymentGroupRequest

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = DeprovisionDeploymentGroupRequest::new().set_name("example");
pub fn set_force<T: Into<bool>>(self, v: T) -> Self

Sets the value of force.

Example
let x = DeprovisionDeploymentGroupRequest::new().set_force(true);
pub fn set_delete_policy<T: Into<DeletePolicy>>(self, v: T) -> Self

Sets the value of delete_policy.

Example
use google_cloud_config_v1::model::delete_deployment_request::DeletePolicy;
let x0 = DeprovisionDeploymentGroupRequest::new().set_delete_policy(DeletePolicy::Delete);
let x1 = DeprovisionDeploymentGroupRequest::new().set_delete_policy(DeletePolicy::Abandon);