#[non_exhaustive]pub struct ExportDeploymentStatefileRequest {
pub parent: String,
pub draft: bool,
/* private fields */
}Expand description
A request to export a state file passed to a ‘ExportDeploymentStatefile’ call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent in whose context the statefile is listed. The parent value is in the format: ‘projects/{project_id}/locations/{location}/deployments/{deployment}’.
draft: boolOptional. If this flag is set to true, the exported deployment state file will be the draft state. This will enable the draft file to be validated before copying it over to the working state on unlock.
Implementations
Sourceimpl ExportDeploymentStatefileRequest
impl ExportDeploymentStatefileRequest