#[non_exhaustive]pub struct ExportRevisionStatefileRequest {
pub parent: String,
/* private fields */
}Expand description
A request to export a state file passed to a ‘ExportRevisionStatefile’ call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent in whose context the statefile is listed. The parent value is in the format: ‘projects/{project_id}/locations/{location}/deployments/{deployment}/revisions/{revision}’.
Implementations