#[non_exhaustive]pub struct ExternalValueSource {
pub source: Option<Source>,
/* private fields */
}Expand description
Configuration for a source of an external value.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: Option<Source>The source of the external value.
Implementations
Sourceimpl ExternalValueSource
impl ExternalValueSource
pub fn new() -> Self
Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
ⓘ
use google_cloud_config_v1::model::DeploymentSource;
let x = ExternalValueSource::new().set_source(Some(
google_cloud_config_v1::model::external_value_source::Source::DeploymentSource(DeploymentSource::default().into())));Sourcepub fn deployment_source(&self) -> Option<&Box<DeploymentSource>>
pub fn deployment_source(&self) -> Option<&Box<DeploymentSource>>
The value of source
if it holds a DeploymentSource, None if the field is not set or
holds a different branch.
Sourcepub fn set_deployment_source<T: Into<Box<DeploymentSource>>>(self, v: T) -> Self
pub fn set_deployment_source<T: Into<Box<DeploymentSource>>>(self, v: T) -> Self
Sets the value of source
to hold a DeploymentSource.
Note that all the setters affecting source are
mutually exclusive.
Example
ⓘ
use google_cloud_config_v1::model::DeploymentSource;
let x = ExternalValueSource::new().set_deployment_source(DeploymentSource::default()/* use setters */);
assert!(x.deployment_source().is_some());Trait Implementations
Sourceimpl Clone for ExternalValueSource
impl Clone for ExternalValueSource
Sourcefn clone(&self) -> ExternalValueSource
fn clone(&self) -> ExternalValueSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExternalValueSource
impl Debug for ExternalValueSource
Sourceimpl Default for ExternalValueSource
impl Default for ExternalValueSource
Sourcefn default() -> ExternalValueSource
fn default() -> ExternalValueSource
Returns the “default value” for a type. Read more
Sourceimpl Message for ExternalValueSource
impl Message for ExternalValueSource
Sourceimpl PartialEq for ExternalValueSource
impl PartialEq for ExternalValueSource
impl StructuralPartialEq for ExternalValueSource