#[non_exhaustive]pub struct ImportStatefileRequest {
pub parent: String,
pub lock_id: i64,
pub skip_draft: bool,
/* private fields */
}Expand description
A request to import a state file passed to a ‘ImportStatefile’ call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent in whose context the statefile is listed. The parent value is in the format: ‘projects/{project_id}/locations/{location}/deployments/{deployment}’.
lock_id: i64Required. Lock ID of the lock file to verify that the user who is importing the state file previously locked the Deployment.
skip_draft: boolOptional.
Implementations
Sourceimpl ImportStatefileRequest
impl ImportStatefileRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_lock_id<T: Into<i64>>(self, v: T) -> Self
pub fn set_lock_id<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_skip_draft<T: Into<bool>>(self, v: T) -> Self
pub fn set_skip_draft<T: Into<bool>>(self, v: T) -> Self