#[non_exhaustive]pub struct ListDeploymentGroupRevisionsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
The request message for the ListDeploymentGroupRevisions method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, which owns this collection of deployment group revisions. Format: ‘projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}’.
page_size: i32Optional. When requesting a page of resources, ‘page_size’ specifies number of resources to return. If unspecified, a sensible default will be used by the server. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringOptional. Token returned by previous call to ‘ListDeploymentGroupRevisions’
which specifies the position in the list from where to continue listing the
deployment group revisions. All other parameters provided to
ListDeploymentGroupRevisions must match the call that provided the page
token.
Implementations
Sourceimpl ListDeploymentGroupRevisionsRequest
impl ListDeploymentGroupRevisionsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListDeploymentGroupRevisionsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListDeploymentGroupRevisionsRequest
impl Clone for ListDeploymentGroupRevisionsRequest
Sourcefn clone(&self) -> ListDeploymentGroupRevisionsRequest
fn clone(&self) -> ListDeploymentGroupRevisionsRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ListDeploymentGroupRevisionsRequest
impl Default for ListDeploymentGroupRevisionsRequest
Sourcefn default() -> ListDeploymentGroupRevisionsRequest
fn default() -> ListDeploymentGroupRevisionsRequest
Sourceimpl PartialEq for ListDeploymentGroupRevisionsRequest
impl PartialEq for ListDeploymentGroupRevisionsRequest
Sourcefn eq(&self, other: &ListDeploymentGroupRevisionsRequest) -> bool
fn eq(&self, other: &ListDeploymentGroupRevisionsRequest) -> bool
self and other values to be equal, and is used by ==.