#[non_exhaustive]pub struct ListResourceChangesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
The request message for the ListResourceChanges method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent in whose context the ResourceChanges are listed. The parent value is in the format: ‘projects/{project_id}/locations/{location}/previews/{preview}’.
page_size: i32Optional. When requesting a page of resource changes, ‘page_size’ specifies number of resource changes to return. If unspecified, at most 500 will be returned. The maximum value is 1000.
page_token: StringOptional. Token returned by previous call to ‘ListResourceChanges’ which specifies the position in the list from where to continue listing the resource changes.
filter: StringOptional. Lists the resource changes that match the filter expression. A filter expression filters the resource changes listed in the response. The expression must be of the form ‘{field} {operator} {value}’ where operators: ‘<’, ‘>’, ‘<=’, ‘>=’, ‘!=’, ‘=’, ‘:’ are supported (colon ‘:’ represents a HAS operator which is roughly synonymous with equality). {field} can refer to a proto or JSON field, or a synthetic field. Field names can be camelCase or snake_case.
Examples:
- Filter by name: name = “projects/foo/locations/us-central1/previews/dep/resourceChanges/baz
order_by: StringOptional. Field to use to sort the list.
Implementations
Sourceimpl ListResourceChangesRequest
impl ListResourceChangesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListResourceChangesRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self