#[non_exhaustive]pub struct ListResourcesResponse {
pub resources: Vec<Resource>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
A response to a ‘ListResources’ call. Contains a list of Resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resources: Vec<Resource>List of Resources.
next_page_token: StringA token to request the next page of resources from the ‘ListResources’ method. The value of an empty string means that there are no more resources to return.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListResourcesResponse
impl ListResourcesResponse
pub fn new() -> Self
Sourcepub fn set_resources<T, V>(self, v: T) -> Self
pub fn set_resources<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListResourcesResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListResourcesResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListResourcesResponse
impl Clone for ListResourcesResponse
Sourcefn clone(&self) -> ListResourcesResponse
fn clone(&self) -> ListResourcesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListResourcesResponse
impl Debug for ListResourcesResponse
Sourceimpl Default for ListResourcesResponse
impl Default for ListResourcesResponse
Sourcefn default() -> ListResourcesResponse
fn default() -> ListResourcesResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListResourcesResponse
impl Message for ListResourcesResponse
Sourceimpl PartialEq for ListResourcesResponse
impl PartialEq for ListResourcesResponse
impl StructuralPartialEq for ListResourcesResponse