#[non_exhaustive]pub struct ListRevisionsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
A request to list Revisions passed to a ‘ListRevisions’ call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent in whose context the Revisions are listed. The parent value is in the format: ‘projects/{project_id}/locations/{location}/deployments/{deployment}’.
page_size: i32When requesting a page of resources, page_size specifies number of
resources to return. If unspecified, at most 500 will be returned. The
maximum value is 1000.
page_token: StringToken returned by previous call to ‘ListRevisions’ which specifies the position in the list from where to continue listing the resources.
filter: StringLists the Revisions that match the filter expression. A filter expression filters the resources listed in the response. The expression must be of the form ‘{field} {operator} {value}’ where operators: ‘<’, ‘>’, ‘<=’, ‘>=’, ‘!=’, ‘=’, ‘:’ are supported (colon ‘:’ represents a HAS operator which is roughly synonymous with equality). {field} can refer to a proto or JSON field, or a synthetic field. Field names can be camelCase or snake_case.
Examples:
-
Filter by name: name = “projects/foo/locations/us-central1/deployments/dep/revisions/bar
-
Filter by labels:
- Resources that have a key called ‘foo’ labels.foo:*
- Resources that have a key called ‘foo’ whose value is ‘bar’ labels.foo = bar
-
Filter by state:
- Revisions in CREATING state. state=CREATING
order_by: StringField to use to sort the list.
Implementations
Sourceimpl ListRevisionsRequest
impl ListRevisionsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListRevisionsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self