#[non_exhaustive]pub struct LockInfo {
pub lock_id: i64,
pub operation: String,
pub info: String,
pub who: String,
pub version: String,
pub create_time: Option<Timestamp>,
/* private fields */
}Expand description
Details about the lock which locked the deployment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.lock_id: i64Unique ID for the lock to be overridden with generation ID in the backend.
operation: StringTerraform operation, provided by the caller.
info: StringExtra information to store with the lock, provided by the caller.
who: Stringuser@hostname when available
version: StringTerraform version
create_time: Option<Timestamp>Time that the lock was taken.
Implementations
Sourceimpl LockInfo
impl LockInfo
pub fn new() -> Self
Sourcepub fn set_lock_id<T: Into<i64>>(self, v: T) -> Self
pub fn set_lock_id<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_operation<T: Into<String>>(self, v: T) -> Self
pub fn set_operation<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_version<T: Into<String>>(self, v: T) -> Self
pub fn set_version<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = LockInfo::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = LockInfo::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = LockInfo::new().set_or_clear_create_time(None::<Timestamp>);Trait Implementations
impl StructuralPartialEq for LockInfo