#[non_exhaustive]pub struct ProvisionDeploymentGroupOperationMetadata {
pub step: ProvisionDeploymentGroupStep,
pub deployment_unit_progresses: Vec<DeploymentUnitProgress>,
/* private fields */
}Expand description
Operation metadata for ProvisionDeploymentGroup and
DeprovisionDeploymentGroup long-running operations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.step: ProvisionDeploymentGroupStepOutput only. The current step of the deployment group operation.
deployment_unit_progresses: Vec<DeploymentUnitProgress>Output only. Progress information for each deployment unit within the operation.
Implementations
Sourceimpl ProvisionDeploymentGroupOperationMetadata
impl ProvisionDeploymentGroupOperationMetadata
pub fn new() -> Self
Sourcepub fn set_step<T: Into<ProvisionDeploymentGroupStep>>(self, v: T) -> Self
pub fn set_step<T: Into<ProvisionDeploymentGroupStep>>(self, v: T) -> Self
Sets the value of step.
Example
ⓘ
use google_cloud_config_v1::model::provision_deployment_group_operation_metadata::ProvisionDeploymentGroupStep;
let x0 = ProvisionDeploymentGroupOperationMetadata::new().set_step(ProvisionDeploymentGroupStep::ValidatingDeploymentGroup);
let x1 = ProvisionDeploymentGroupOperationMetadata::new().set_step(ProvisionDeploymentGroupStep::AssociatingDeploymentsToDeploymentGroup);
let x2 = ProvisionDeploymentGroupOperationMetadata::new().set_step(ProvisionDeploymentGroupStep::ProvisioningDeploymentUnits);Sourcepub fn set_deployment_unit_progresses<T, V>(self, v: T) -> Self
pub fn set_deployment_unit_progresses<T, V>(self, v: T) -> Self
Sets the value of deployment_unit_progresses.
Example
ⓘ
use google_cloud_config_v1::model::DeploymentUnitProgress;
let x = ProvisionDeploymentGroupOperationMetadata::new()
.set_deployment_unit_progresses([
DeploymentUnitProgress::default()/* use setters */,
DeploymentUnitProgress::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for ProvisionDeploymentGroupOperationMetadata
impl Clone for ProvisionDeploymentGroupOperationMetadata
Sourcefn clone(&self) -> ProvisionDeploymentGroupOperationMetadata
fn clone(&self) -> ProvisionDeploymentGroupOperationMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ProvisionDeploymentGroupOperationMetadata
impl Default for ProvisionDeploymentGroupOperationMetadata
Sourcefn default() -> ProvisionDeploymentGroupOperationMetadata
fn default() -> ProvisionDeploymentGroupOperationMetadata
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ProvisionDeploymentGroupOperationMetadata
impl PartialEq for ProvisionDeploymentGroupOperationMetadata
Sourcefn eq(&self, other: &ProvisionDeploymentGroupOperationMetadata) -> bool
fn eq(&self, other: &ProvisionDeploymentGroupOperationMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProvisionDeploymentGroupOperationMetadata