#[non_exhaustive]pub struct ProvisionDeploymentGroupRequest {
pub name: String,
pub deployment_specs: HashMap<String, DeploymentSpec>,
/* private fields */
}Expand description
The request message for the ProvisionDeploymentGroup method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the deployment group to provision. Format: ‘projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}’.
deployment_specs: HashMap<String, DeploymentSpec>Optional. The deployment specs of the deployment units to be created within
the same project and location of the deployment group. The key is the unit
ID, and the value is the DeploymentSpec. Provisioning will fail if a
deployment_spec has a deployment_id that matches an existing deployment
in the same project and location. If an existing deployment was part of the
last successful revision but is no longer in the current DeploymentGroup’s
deployment_units, it will be recreated if included in deployment_specs.
Implementations
Sourceimpl ProvisionDeploymentGroupRequest
impl ProvisionDeploymentGroupRequest
pub fn new() -> Self
Sourcepub fn set_deployment_specs<T, K, V>(self, v: T) -> Self
pub fn set_deployment_specs<T, K, V>(self, v: T) -> Self
Sets the value of deployment_specs.
Example
use google_cloud_config_v1::model::DeploymentSpec;
let x = ProvisionDeploymentGroupRequest::new().set_deployment_specs([
("key0", DeploymentSpec::default()/* use setters */),
("key1", DeploymentSpec::default()/* use (different) setters */),
]);Trait Implementations
Sourceimpl Clone for ProvisionDeploymentGroupRequest
impl Clone for ProvisionDeploymentGroupRequest
Sourcefn clone(&self) -> ProvisionDeploymentGroupRequest
fn clone(&self) -> ProvisionDeploymentGroupRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ProvisionDeploymentGroupRequest
impl Default for ProvisionDeploymentGroupRequest
Sourcefn default() -> ProvisionDeploymentGroupRequest
fn default() -> ProvisionDeploymentGroupRequest
Sourceimpl PartialEq for ProvisionDeploymentGroupRequest
impl PartialEq for ProvisionDeploymentGroupRequest
Sourcefn eq(&self, other: &ProvisionDeploymentGroupRequest) -> bool
fn eq(&self, other: &ProvisionDeploymentGroupRequest) -> bool
self and other values to be equal, and is used by ==.