#[non_exhaustive]pub struct UpdateDeploymentGroupRequest {
pub update_mask: Option<FieldMask>,
pub deployment_group: Option<DeploymentGroup>,
pub request_id: String,
/* private fields */
}Expand description
A request message for updating a deployment group
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. Field mask used to specify the fields to be overwritten in the Deployment Group resource by the update.
The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
deployment_group: Option<DeploymentGroup>Required. DeploymentGroup to update.
The deployment group’s name field is used to identify the resource to be
updated. Format:
projects/{project}/locations/{location}/deploymentGroups/{deployment_group_id}
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl UpdateDeploymentGroupRequest
impl UpdateDeploymentGroupRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateDeploymentGroupRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateDeploymentGroupRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateDeploymentGroupRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_deployment_group<T>(self, v: T) -> Selfwhere
T: Into<DeploymentGroup>,
pub fn set_deployment_group<T>(self, v: T) -> Selfwhere
T: Into<DeploymentGroup>,
Sets the value of deployment_group.
Example
use google_cloud_config_v1::model::DeploymentGroup;
let x = UpdateDeploymentGroupRequest::new().set_deployment_group(DeploymentGroup::default()/* use setters */);Sourcepub fn set_or_clear_deployment_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeploymentGroup>,
pub fn set_or_clear_deployment_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeploymentGroup>,
Sets or clears the value of deployment_group.
Example
use google_cloud_config_v1::model::DeploymentGroup;
let x = UpdateDeploymentGroupRequest::new().set_or_clear_deployment_group(Some(DeploymentGroup::default()/* use setters */));
let x = UpdateDeploymentGroupRequest::new().set_or_clear_deployment_group(None::<DeploymentGroup>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = UpdateDeploymentGroupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for UpdateDeploymentGroupRequest
impl Clone for UpdateDeploymentGroupRequest
Sourcefn clone(&self) -> UpdateDeploymentGroupRequest
fn clone(&self) -> UpdateDeploymentGroupRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateDeploymentGroupRequest
impl Debug for UpdateDeploymentGroupRequest
Sourceimpl Default for UpdateDeploymentGroupRequest
impl Default for UpdateDeploymentGroupRequest
Sourcefn default() -> UpdateDeploymentGroupRequest
fn default() -> UpdateDeploymentGroupRequest
Sourceimpl PartialEq for UpdateDeploymentGroupRequest
impl PartialEq for UpdateDeploymentGroupRequest
Sourcefn eq(&self, other: &UpdateDeploymentGroupRequest) -> bool
fn eq(&self, other: &UpdateDeploymentGroupRequest) -> bool
self and other values to be equal, and is used by ==.