#[non_exhaustive]pub struct CreateDeploymentGroupRequest {
pub parent: String,
pub deployment_group_id: String,
pub deployment_group: Option<DeploymentGroup>,
pub request_id: String,
/* private fields */
}Expand description
A request to create a deployment group
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent in whose context the Deployment Group is created. The parent value is in the format: ‘projects/{project_id}/locations/{location}’
deployment_group_id: StringRequired. The deployment group ID.
deployment_group: Option<DeploymentGroup>Required. [Deployment Group][] resource to create
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateDeploymentGroupRequest
impl CreateDeploymentGroupRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_deployment_group_id<T: Into<String>>(self, v: T) -> Self
pub fn set_deployment_group_id<T: Into<String>>(self, v: T) -> Self
Sets the value of deployment_group_id.
Example
let x = CreateDeploymentGroupRequest::new().set_deployment_group_id("example");Sourcepub fn set_deployment_group<T>(self, v: T) -> Selfwhere
T: Into<DeploymentGroup>,
pub fn set_deployment_group<T>(self, v: T) -> Selfwhere
T: Into<DeploymentGroup>,
Sets the value of deployment_group.
Example
use google_cloud_config_v1::model::DeploymentGroup;
let x = CreateDeploymentGroupRequest::new().set_deployment_group(DeploymentGroup::default()/* use setters */);Sourcepub fn set_or_clear_deployment_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeploymentGroup>,
pub fn set_or_clear_deployment_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeploymentGroup>,
Sets or clears the value of deployment_group.
Example
use google_cloud_config_v1::model::DeploymentGroup;
let x = CreateDeploymentGroupRequest::new().set_or_clear_deployment_group(Some(DeploymentGroup::default()/* use setters */));
let x = CreateDeploymentGroupRequest::new().set_or_clear_deployment_group(None::<DeploymentGroup>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateDeploymentGroupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateDeploymentGroupRequest
impl Clone for CreateDeploymentGroupRequest
Sourcefn clone(&self) -> CreateDeploymentGroupRequest
fn clone(&self) -> CreateDeploymentGroupRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateDeploymentGroupRequest
impl Debug for CreateDeploymentGroupRequest
Sourceimpl Default for CreateDeploymentGroupRequest
impl Default for CreateDeploymentGroupRequest
Sourcefn default() -> CreateDeploymentGroupRequest
fn default() -> CreateDeploymentGroupRequest
impl StructuralPartialEq for CreateDeploymentGroupRequest