#[non_exhaustive]pub struct DeploymentUnitProgress {
pub unit_id: String,
pub deployment: String,
pub state: State,
pub state_description: String,
pub deployment_operation_summary: Option<DeploymentOperationSummary>,
pub error: Option<Status>,
pub intent: Intent,
/* private fields */
}Expand description
The progress of a deployment unit provisioning or deprovisioning.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.unit_id: StringOutput only. The unit id of the deployment unit to be provisioned.
deployment: StringOutput only. The name of the deployment to be provisioned. Format: ‘projects/{project}/locations/{location}/deployments/{deployment}’.
state: StateOutput only. The current step of the deployment unit provisioning.
state_description: StringOutput only. Additional information regarding the current state.
deployment_operation_summary: Option<DeploymentOperationSummary>Output only. The summary of the deployment operation.
error: Option<Status>Output only. Holds the error status of the deployment unit provisioning.
intent: IntentOutput only. The intent of the deployment unit.
Implementations
Sourceimpl DeploymentUnitProgress
impl DeploymentUnitProgress
pub fn new() -> Self
Sourcepub fn set_unit_id<T: Into<String>>(self, v: T) -> Self
pub fn set_unit_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_deployment<T: Into<String>>(self, v: T) -> Self
pub fn set_deployment<T: Into<String>>(self, v: T) -> Self
Sets the value of deployment.
Example
let x = DeploymentUnitProgress::new().set_deployment("example");Sourcepub fn set_state<T: Into<State>>(self, v: T) -> Self
pub fn set_state<T: Into<State>>(self, v: T) -> Self
Sets the value of state.
Example
use google_cloud_config_v1::model::deployment_unit_progress::State;
let x0 = DeploymentUnitProgress::new().set_state(State::Queued);
let x1 = DeploymentUnitProgress::new().set_state(State::ApplyingDeployment);
let x2 = DeploymentUnitProgress::new().set_state(State::Succeeded);Sourcepub fn set_state_description<T: Into<String>>(self, v: T) -> Self
pub fn set_state_description<T: Into<String>>(self, v: T) -> Self
Sets the value of state_description.
Example
let x = DeploymentUnitProgress::new().set_state_description("example");Sourcepub fn set_deployment_operation_summary<T>(self, v: T) -> Selfwhere
T: Into<DeploymentOperationSummary>,
pub fn set_deployment_operation_summary<T>(self, v: T) -> Selfwhere
T: Into<DeploymentOperationSummary>,
Sets the value of deployment_operation_summary.
Example
use google_cloud_config_v1::model::DeploymentOperationSummary;
let x = DeploymentUnitProgress::new().set_deployment_operation_summary(DeploymentOperationSummary::default()/* use setters */);Sourcepub fn set_or_clear_deployment_operation_summary<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeploymentOperationSummary>,
pub fn set_or_clear_deployment_operation_summary<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeploymentOperationSummary>,
Sets or clears the value of deployment_operation_summary.
Example
use google_cloud_config_v1::model::DeploymentOperationSummary;
let x = DeploymentUnitProgress::new().set_or_clear_deployment_operation_summary(Some(DeploymentOperationSummary::default()/* use setters */));
let x = DeploymentUnitProgress::new().set_or_clear_deployment_operation_summary(None::<DeploymentOperationSummary>);Sourcepub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
Sourcepub fn set_intent<T: Into<Intent>>(self, v: T) -> Self
pub fn set_intent<T: Into<Intent>>(self, v: T) -> Self
Sets the value of intent.
Example
use google_cloud_config_v1::model::deployment_unit_progress::Intent;
let x0 = DeploymentUnitProgress::new().set_intent(Intent::CreateDeployment);
let x1 = DeploymentUnitProgress::new().set_intent(Intent::UpdateDeployment);
let x2 = DeploymentUnitProgress::new().set_intent(Intent::DeleteDeployment);Trait Implementations
Sourceimpl Clone for DeploymentUnitProgress
impl Clone for DeploymentUnitProgress
Sourcefn clone(&self) -> DeploymentUnitProgress
fn clone(&self) -> DeploymentUnitProgress
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more