#[non_exhaustive]pub struct DeprovisionDeploymentGroupRequest {
pub name: String,
pub force: bool,
pub delete_policy: DeletePolicy,
/* private fields */
}Expand description
The request message for the DeprovisionDeploymentGroup method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the deployment group to deprovision. Format: ‘projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}’.
force: boolOptional. If set to true, this option is propagated to the deletion of each deployment in the group. This corresponds to the ‘force’ field in DeleteDeploymentRequest.
delete_policy: DeletePolicyOptional. Policy on how resources within each deployment should be handled during deletion. This policy is applied globally to the deletion of all deployments in this group. This corresponds to the ‘delete_policy’ field in DeleteDeploymentRequest.
Implementations
Sourceimpl DeprovisionDeploymentGroupRequest
impl DeprovisionDeploymentGroupRequest
pub fn new() -> Self
Sourcepub fn set_delete_policy<T: Into<DeletePolicy>>(self, v: T) -> Self
pub fn set_delete_policy<T: Into<DeletePolicy>>(self, v: T) -> Self
Sets the value of delete_policy.
Example
ⓘ
use google_cloud_config_v1::model::delete_deployment_request::DeletePolicy;
let x0 = DeprovisionDeploymentGroupRequest::new().set_delete_policy(DeletePolicy::Delete);
let x1 = DeprovisionDeploymentGroupRequest::new().set_delete_policy(DeletePolicy::Abandon);Trait Implementations
Sourceimpl Clone for DeprovisionDeploymentGroupRequest
impl Clone for DeprovisionDeploymentGroupRequest
Sourcefn clone(&self) -> DeprovisionDeploymentGroupRequest
fn clone(&self) -> DeprovisionDeploymentGroupRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for DeprovisionDeploymentGroupRequest
impl Default for DeprovisionDeploymentGroupRequest
Sourcefn default() -> DeprovisionDeploymentGroupRequest
fn default() -> DeprovisionDeploymentGroupRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for DeprovisionDeploymentGroupRequest
impl PartialEq for DeprovisionDeploymentGroupRequest
Sourcefn eq(&self, other: &DeprovisionDeploymentGroupRequest) -> bool
fn eq(&self, other: &DeprovisionDeploymentGroupRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeprovisionDeploymentGroupRequest